#  QuantumFlow: A Quantum Algorithms Development Toolkit

A cross-compiler for gate based models of quantum computing

![Build Status](https://github.com/gecrooks/quantumflow-dev/workflows/Build/badge.svg) [![Documentation Status](https://readthedocs.org/projects/quantumflow/badge/?version=latest)](https://quantumflow.readthedocs.io/en/latest/?badge=latest)


[Source](https://github.com/gecrooks/quantumflow)


## Installation for development

```
$ git clone https://github.com/gecrooks/quantumflow.git
$ cd quantumflow
$ pip install -e .[dev]
```


